ATLAS Rucio Integration Test-bed — Rucio 1.12.2 documentation

# ATLAS Rucio Integration Test-bed

Authentication

DNS: http://atlas-rucio-auth.cern.ch/

- voatlas298, AWStats
- voatlas299, AWStats

Load Balancer/Proxy/Cache

DNS: http://atlas-rucio.cern.ch/

- voatlas304, Munin monitoring
- voatlas305, Munin monitoring

Reader Backend

- voatlas300, AWStats
- voatlas301, AWStats

Writer Backend

- voatlas302, AWStats
- voatlas303, AWStats

Daemons

- voatlas63

Graphite

- voatlas70, Monitoring

Nagios

- voatlas143, Nagios monitoring